==> parcel-bundler-vue-1.6.3.tgz: package/lib/worker.js <==
'use strict';

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _from = require('babel-runtime/core-js/array/from');

var _from2 = _interopRequireDefault(_from);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _assign = require('babel-runtime/core-js/object/assign');

var _assign2 = _interopRequireDefault(_assign);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

require('v8-compile-cache');
var Parser = require('./Parser');

var parser = void 0;

exports.init = function (options, callback) {
  parser = new Parser(options || {});
  (0, _assign2.default)(process.env, options.env || {});
  process.env.HMR_PORT = options.hmrPort;
  process.env.HMR_HOSTNAME = options.hmrHostname;
  callback();
};

exports.run = function () {
  var _ref = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee(path, pkg, options, isWarmUp, callback) {
    var asset, returned;
    return _regenerator2.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.prev = 0;

            options.isWarmUp = isWarmUp;
            asset = parser.getAsset(path, pkg, options);
            _context.next = 5;
            return asset.process();

          case 5:

            callback(null, {
              dependencies: (0, _from2.default)(asset.dependencies.values()),
              generated: asset.generated,
              hash: asset.hash,
              cacheData: asset.cacheData
            });
            _context.next = 14;
            break;

          case 8:
            _context.prev = 8;
            _context.t0 = _context['catch'](0);
            returned = _context.t0;


            if (asset) {
              returned = asset.generateErrorMessage(returned);
            }

            returned.fileName = path;
            callback(returned);

          case 14:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, this, [[0, 8]]);
  }));

  return function (_x, _x2, _x3, _x4, _x5) {
    return _ref.apply(this, arguments);
  };
}();

process.on('unhandledRejection', function (err) {
  // ERR_IPC_CHANNEL_CLOSED happens when the worker is killed before it finishes processing
  if (err.code !== 'ERR_IPC_CHANNEL_CLOSED') {
    console.error('Unhandled promise rejection:', err.stack);
  }
});

==> parcel-bundler-vue-2.0.0.tgz: package/lib/worker.js <==
'use strict';

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _from = require('babel-runtime/core-js/array/from');

var _from2 = _interopRequireDefault(_from);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _assign = require('babel-runtime/core-js/object/assign');

var _assign2 = _interopRequireDefault(_assign);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

require('v8-compile-cache');
var Parser = require('./Parser');

var parser = void 0;

exports.init = function (options, callback) {
  parser = new Parser(options || {});
  (0, _assign2.default)(process.env, options.env || {});
  process.env.HMR_PORT = options.hmrPort;
  process.env.HMR_HOSTNAME = options.hmrHostname;
  callback();
};

exports.run = function () {
  var _ref = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee(path, contents, pkg, options, callback) {
    var asset, returned;
    return _regenerator2.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.prev = 0;
            asset = parser.getAsset(path, pkg, options, contents);
            _context.next = 4;
            return asset.process();

          case 4:

            callback(null, {
              dependencies: (0, _from2.default)(asset.dependencies.values()),
              generated: asset.generated,
              hash: asset.hash,
              cacheData: asset.cacheData
            });
            _context.next = 13;
            break;

          case 7:
            _context.prev = 7;
            _context.t0 = _context['catch'](0);
            returned = _context.t0;


            if (asset) {
              returned = asset.generateErrorMessage(returned);
            }

            returned.fileName = path;
            callback(returned);

          case 13:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, this, [[0, 7]]);
  }));

  return function (_x, _x2, _x3, _x4, _x5) {
    return _ref.apply(this, arguments);
  };
}();
